@@ -28,6 +28,7 @@
 #include "debug_p.h"
 #include "getconfigoperation.h"
 #include "configserializer_p.h"
+#include "log.h"
 
 #include <QDBusConnection>
 #include <QDBusPendingCall>
@@ -68,6 +69,7 @@ BackendManager::BackendManager()
     , mLoader(0)
     , mMethod(OutOfProcess)
 {
+    Log::instance();
     // Decide wether to run in, or out-of-process
 
     // if KSCREEN_BACKEND_INPROCESS is set explicitely, we respect that
@@ -288,7 +290,6 @@ void BackendManager::emitBackendReady()
 
 void BackendManager::startBackend(const QString &backend, const QVariantMap &arguments)
 {
-    qCDebug(KSCREEN) << "starting external backend launcher for" << backend;
     // This will autostart the launcher if it's not running already, calling
     // requestBackend(backend) will:
     //   a) if the launcher is started it will force it to load the correct backend,
